Notebooks
========================================================================================

.. toctree::

    Example full run <notebooks/Example_full_run>
    Building a list of onesources <notebooks/Building_list_of_onesources>
    Example of usage of magSvc <notebooks/Example_of_usage_of_magSvc>
    Data retrieval <notebooks/Data_retrieval>
    Testing fit of one object of the catalogue <notebooks/Testing_fit_of_one_object_of_the_catalogue>
    Example of the cosmology class <notebooks/Example_cosmo>
    Demonstration of SED objects <notebooks/Example_SED_manipulation>
